@@ -163,7 +163,7 @@ class AltiumRun:
         :param function_name: The name of the function to run in the Altium script as string.
         :param args: The arguments given to the Altium script function.
         """
-        self._generate_script_from_base("updateSitNum0302.pas", {})
+        self._generate_script_from_base_top("updateSitNum0302.pas")
         self.add_script(self._project_path + "/updateSitNum0302.pas")
         self.set_function_name(function_name)
         self.set_function_parameters(*args)
@@ -285,6 +285,21 @@ class AltiumRun:
         destination = self._project_path + '/' + name
         self._generate_script_from_source(origin, destination, variables)
 
+
+    def _generate_script_from_base_top(self, name: str) -> None:
+        origin = os.path.dirname(os.path.abspath(__file__)) + '\\scriptingbase\\' + name
+        destination = self._project_path + '/' + name
+        self._generate_script_from_source_top(origin, destination)
+    def _generate_script_from_source_top(self, origin: str, destination: str) -> None:
+        f_or = open(origin, 'r')
+        f_de = open(destination, 'w')
+        line = f_or.readline()
+        while line:
+            f_de.write(line)
+            line = f_or.readline()
+        f_or.close()
+        f_de.close()
+
     def _generate_script_from_source(self, origin: str, destination: str, variables: Dict[str, Any] = {}) -> None:
         f_or = open(origin, 'r')
         f_de = open(destination, 'w')
